@@ -76,7 +76,7 @@ class AbstractSolarluxUser(AbstractBaseUser, PermissionsMixin):
     sap_plant = models.CharField(_('SAP Werk'), max_length=4, null=True, blank=True)
     country_code = models.CharField(_('Länderkürzel'), max_length=2, null=True, blank=True)
     mobile_number = models.CharField(_('Mobilnummer'), max_length=255, null=True, blank=True)
-    department = models.CharField(_('Abteilung'), max_length=50, null=True, blank=True)
+    um_department = models.CharField(_('Abteilung'), max_length=50, null=True, blank=True)
 
     objects = UserManager()
 
