@@ -88,9 +88,9 @@ class TokenAuthenticator:
         user.sap_pernr = token_data["sapPernr"] if "sapPernr" in token_data else None
         user.sap_sales_org = token_data["sapSalesOrg"] if "sapSalesOrg" in token_data else None
         user.sap_company_code = token_data["sapCompanyCode"] if "sapCompanyCode" in token_data else None
-        user.sap_user_name = token_data["sapUserName"] if "sapUserName" in token_data else None
+        user.sap_plant = token_data["sapPlant"] if "sapPlant" in token_data else None
         user.country_code = token_data["countryCode"] if "countryCode" in token_data else None
-        user.department = token_data["department"] if "department" in token_data else None
+        user.um_department = token_data["department"] if "department" in token_data else None
         user.mobile_number = token_data["mobileNumber"] if "mobileNumber" in token_data else None
 
         user_groups = user.groups.all()
