@@ -100,9 +100,6 @@ class CallbackView(View):
                         "domain": settings.OAUTH_COOKIE_DOMAIN,
                     }
                     response.set_cookie("access_token", access_token, **cookie_args)
-                    response.set_cookie(
-                        "expiration_time", expiration_time, **cookie_args
-                    )
                     response.set_cookie("refresh_token", refresh_token, **cookie_args)
                     return response
         else:
@@ -119,7 +116,7 @@ class LogoutView(LogoutView):
         domain = settings.OAUTH_COOKIE_DOMAIN
 
         # clear the SSO cookies to logout from all portal apps
-        for c in ["access_token", "expiration_time", "refresh_token"]:
+        for c in ["access_token", "refresh_token"]:
             response.set_cookie(c, max_age=0, domain=domain)
 
         return response
